/**
 *
 * Mozilla Public License Notice
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1  (the "License"); you may  not use this  file except in
 * compliance with the  License. You may obtain a  copy of the License
 * at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the  License  for  the   specific  language  governing  rights  and
 * limitations under the License.
 *
 * The  Original Code and  Idea is  the Hit-a-Hint  Mozilla extension.
 * The Initial  Developer of the Original  Code and the  Idea is Pekka
 * P. Sillanpaa.  Portions created  by Initial Developer are Copyright
 * (C) 2004.  All Rights Reserved.
 *
 * Contributor(s): Pekka Sillanpaa, Paul Stone
 *
 */


////////////////////////////////////////////////////////////////////////////////
// settings dialog code
////////////////////////////////////////////////////////////////////////////////

var hahSettings =
{
  init: function() {
    var elem; 
    var prefVal;
    var pref;
    
    for (i in HAH_PREFS)  {
      pref = HAH_PREFS[i];
      elem = document.getElementById(pref.name);
      if (elem == null) continue; // no UI for pref
      prefVal = hahPrefs.get(pref);
      switch (elem.nodeName) {
        case 'textbox':
          elem.value = prefVal;
          break;
        case 'checkbox':
          elem.checked = prefVal;
          break;
        case 'radio':
          if (prefVal) elem.radioGroup.selectedItem = elem;
          break;
        case 'keyinputbox':
          elem.combinedValue = prefVal;
      }
    }
  },


  doOK: function() {
    var value;
    var elem;
    var pref;
    
    for (i in HAH_PREFS) {
      pref = HAH_PREFS[i];
      elem = document.getElementById(pref.name);
      if (elem == null) continue; // no UI for pref
      switch (elem.nodeName) {
        case 'textbox':
          value = elem.value;
          break;
        case 'checkbox':
          value = elem.checked;
          break;
        case 'radio':
          value = elem.selected;
          break;
        case 'keyinputbox':
          value = elem.combinedValue;
      }
      hahPrefs.set(pref, value);
    }
    return true;
  },

  doCancel: function() {
    return true;
  }
}


////////////////////////////////////////////////////////////////////////////////
// preference setter/getter code
////////////////////////////////////////////////////////////////////////////////

function HaHPref(name, type, value) {
  this.name = name;
  this.type = type;
  this.defaultValue = value;
}

var HAH_BOOL = 1;
var HAH_INT = 2;
var HAH_STRING = 3;
var HAH_PREFS = {
  ENABLED:           new HaHPref('enabled',               HAH_BOOL,   true),
  MAGIC_KEY:         new HaHPref('keys.magic',            HAH_INT,    512), // space
  START_KEY:         new HaHPref('keys.start',            HAH_INT,    3008), // ','
  HINT_STYLE:        new HaHPref('hints.style',           HAH_STRING, 'z-index:500;width:auto;height:auto;font-weight:normal;font-size:small;color:ButtonText;background-color:ButtonFace;font-family:sans-serif;border-color:ButtonHighlight;border-width:1px;border-style:solid;-moz-border-radius:0.5em;-moz-opacity:0.8;padding:0px 3px 0px 3px;'),              
  HINT_STYLE_FOCUS:  new HaHPref('hints.styleFocus',      HAH_STRING, 'z-index:510;width:auto;height:auto;font-weight:normal;font-size:medium;color:Black;background-color:#abcdef;font-family:sans-serif;border-color:ButtonHighlight;border-width:2px;border-style:solid;-moz-border-radius:0.5em;padding:0px 3px 0px 3px;'),
  HINT_TEXT_LINKS:   new HaHPref('hints.textLinks',       HAH_BOOL,   true),
  HINT_IMAGE_LINKS:  new HaHPref('hints.imageLinks',      HAH_BOOL,   true),
  HINT_OTHER_TAGS:   new HaHPref('hints.otherTags',       HAH_STRING, 'input;textarea;select;button;isindex'),           
  HINT_FORCE_NUMERIC: new HaHPref('hints.forceNumeric',   HAH_BOOL,   true),
  KEYINPUT_IN_FORMS: new HaHPref('keys.allowInputInForm', HAH_BOOL,   false), 
  GENERATE_MAGIC:    new HaHPref('keys.generateMagic',    HAH_BOOL,   false),
  NUMBER_KEYS:       new HaHPref('keys.numbers',          HAH_STRING, '0123456789')
};

var hahPrefs = 
{
  nsIPrefs: null,
  
  getPreferences: function() {
    if (hahPrefs.nsIPrefs == null) {
      var PREFID = '@mozilla.org/preferences;1';
      var nsIPrefBranch = Components.interfaces.nsIPrefBranch;
      hahPrefs.nsIPrefs = Components.classes[PREFID].getService(nsIPrefBranch);
    }
    return hahPrefs.nsIPrefs;
  },

  set: function(hahPref, prefVal) {
    var prefs = hahPrefs.getPreferences();
    prefString = "extensions.hah." + hahPref.name;
    
    switch (hahPref.type) {
      case HAH_BOOL:
        prefs.setBoolPref(prefString, prefVal);
        break;
      case HAH_INT:
        prefs.setIntPref(prefString, prefVal);
        break;
      case HAH_STRING:
        prefs.setCharPref(prefString, prefVal);
        break;
    }       
  },

  get: function(hahPref) {
    var prefs = hahPrefs.getPreferences();
    prefString = "extensions.hah." + hahPref.name;
    
    switch (hahPref.type) {
      case HAH_BOOL:
        return prefs.getBoolPref(prefString);
        break;
      case HAH_INT:
        return prefs.getIntPref(prefString);
        break;
      case HAH_STRING:
        return prefs.getCharPref(prefString);
        break;
    }
    return null;
  },

  setDefaultPreferences: function() {
    var prefs = hahPrefs.getPreferences();
    var name;
    var defaultPref;

//    if (prefs.prefHasUserValue("extensions.hah.keys.magic") && (this.get(HAH_PREFS.MAGIC_KEY) < 200 || this.get(HAH_PREFS.START_KEY) < 200)) {
//      alert("Please update your Hit-a-Hint key settings from Tools->Extensions->Options panel. Version 0.4 (and older) keycodes won't work anymore.");
//    }

    for (i in HAH_PREFS) {
      defaultPref = HAH_PREFS[i];
      name = "extensions.hah." + defaultPref.name;
      if (!prefs.prefHasUserValue(name)) {
        switch (defaultPref.type) {
          case HAH_BOOL:
            prefs.setBoolPref(name, defaultPref.defaultValue);
            break;
          case HAH_INT:
            prefs.setIntPref(name, defaultPref.defaultValue);
            break;
          case HAH_STRING:
            prefs.setCharPref(name, defaultPref.defaultValue);
        }
      }
    }
  }
}

